@@ -128,9 +128,9 @@ function get_chart_tether_data(handler, coin_or_token, frequency) {
     });
 }
 
-function get_chart_twitter_data(handler) {
-    $.get('/charts/twitter').done(function(response) {
-        handler(response)
+function get_chart_twitter_data(handler, project, frequency) {
+    $.get('/charts/twitter/' + project + '/' + frequency).done(function(response) {
+        handler(response, project, frequency)
     })
     .fail(function(xhr, status, error) {
         process_fail(xhr);
@@ -138,12 +138,16 @@ function get_chart_twitter_data(handler) {
 }
 
 function captcha() {
-    const _captcha_ids = ['login_image_captcha', 'signup_image_captcha'];
-    for (const x of _captcha_ids) {
-        $.get('/parties/captcha', function (data) {
+    const _captcha_ids = [
+        'login_image_captcha',
+        'signup_image_captcha',
+        'contact_image_captcha'
+    ];
+    $.get('/parties/captcha', function (data) {
+        for (const x of _captcha_ids) {
             document.getElementById(x).setAttribute(
                 'src', `data:image/png;base64,${data['captcha']}`
             );
-        });
-    }
+        }
+    });
 }
