@@ -55,6 +55,9 @@ from xtcryptosignals.settings_exchanges import (
     DCOIN,
     BITMAX,
     BILAXY,
+    BITSTAMP,
+    KUCOIN,
+    COINBASE_PRO,
 )  # noqa
 
 __all__ = [
@@ -75,6 +78,9 @@ __all__ = [
     "DCOIN",
     "BITMAX",
     "BILAXY",
+    "BITSTAMP",
+    "KUCOIN",
+    "COINBASE_PRO",
     "TICKER_SCHEDULE",
     "HISTORY_FREQUENCY",
     "PRICE_CHANGE_FREQUENCIES",
