@@ -23,6 +23,9 @@ COINBENE = "coinbene"
 DCOIN = "dcoin"
 BITMAX = "bitmax"
 BILAXY = "bilaxy"
+BITSTAMP = "bitstamp"
+KUCOIN = "kucoin"
+COINBASE_PRO = "coinbase_pro"
 
 
 EXCHANGES = [
@@ -40,6 +43,9 @@ EXCHANGES = [
     DCOIN,
     BITMAX,
     BILAXY,
+    BITSTAMP,
+    KUCOIN,
+    COINBASE_PRO,
 ]
 
 
@@ -52,8 +58,10 @@ SYMBOLS_PER_EXCHANGE.append(
             "pairs": [
                 ("BTC", "USDT"),
                 ("ETH", "USDT"),
+                ("ETH", "BTC"),
                 ("LTC", "USDT"),
                 ("BNB", "USDT"),
+                ("BNB", "BTC"),
                 ("XRP", "USDT"),
                 ("XLM", "USDT"),
                 ("XMR", "USDT"),
@@ -73,9 +81,9 @@ SYMBOLS_PER_EXCHANGE.append(
     }
 )
 
-# Binance DEX
+# Bitstamp
 SYMBOLS_PER_EXCHANGE.append(
-    {BINANCE_DEX: {"pairs": [("LTO", "BNB"),], "single_request": True,}}
+    {BITSTAMP: {"pairs": [("BTC", "USD"), ("ETH", "USD"),]}}
 )
 
 # OKEx
@@ -83,9 +91,14 @@ SYMBOLS_PER_EXCHANGE.append(
     {OKEX: {"pairs": [("BTC", "USDT"), ("ETH", "USDT"), ("LTC", "USDT"),]}}
 )
 
-# IDEX
+# Coinbase Pro
 SYMBOLS_PER_EXCHANGE.append(
-    {IDEX: {"pairs": [("LTO", "ETH"), ("LQD", "ETH"), ("IDEX", "ETH"),]}}
+    {COINBASE_PRO: {"pairs": [("BTC", "USD"), ("ETH", "USD"),]}}
+)
+
+# Kucoin
+SYMBOLS_PER_EXCHANGE.append(
+    {KUCOIN: {"pairs": [("BTC", "USDT"), ("ETH", "USDT"),]}}
 )
 
 # BIBOX
@@ -93,16 +106,6 @@ SYMBOLS_PER_EXCHANGE.append(
     {BIBOX: {"pairs": [("BTC", "USDT"), ("ETH", "USDT"), ("LTC", "USDT"),]}}
 )
 
-# OKCoin
-SYMBOLS_PER_EXCHANGE.append(
-    {OKCOIN: {"pairs": [("BTC", "USD"), ("ETH", "USD"), ("LTC", "USD"),]}}
-)
-
-# Coinbene
-SYMBOLS_PER_EXCHANGE.append(
-    {COINBENE: {"pairs": [("BTC", "USDT"), ("ETH", "USDT"), ("LTC", "USDT"),]}}
-)
-
 # Bitmax
 SYMBOLS_PER_EXCHANGE.append(
     {
@@ -118,6 +121,21 @@ SYMBOLS_PER_EXCHANGE.append(
     }
 )
 
+# IDEX
+SYMBOLS_PER_EXCHANGE.append(
+    {IDEX: {"pairs": [("LTO", "ETH"), ("LQD", "ETH"), ("IDEX", "ETH"),]}}
+)
+
+# OKCoin
+SYMBOLS_PER_EXCHANGE.append(
+    {OKCOIN: {"pairs": [("BTC", "USD"), ("ETH", "USD"), ("LTC", "USD"),]}}
+)
+
+# Coinbene
+SYMBOLS_PER_EXCHANGE.append(
+    {COINBENE: {"pairs": [("BTC", "USDT"), ("ETH", "USDT"), ("LTC", "USDT"),]}}
+)
+
 # Hotbit
 SYMBOLS_PER_EXCHANGE.append(
     {
@@ -150,6 +168,11 @@ SYMBOLS_PER_EXCHANGE.append(
     {UPHOLD: {"pairs": [("BTC", "USD"), ("ETH", "USD"), ("LTC", "USD"),]}}
 )
 
+# Binance DEX
+SYMBOLS_PER_EXCHANGE.append(
+    {BINANCE_DEX: {"pairs": [("LTO", "BNB"),], "single_request": True,}}
+)
+
 # DCoin
 SYMBOLS_PER_EXCHANGE.append({DCOIN: {"pairs": [], "single_request": True,}})
 
@@ -178,3 +201,5 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
     "LQD": {"pair": "ETH", "name": BILAXY,},
     "CARD": {"pair": "ETH", "name": HOTBIT,},
 }
+
+# Checks EXCHANGES_AND_PAIRS_OF_REFERENCE against SYMBOLS_PER_EXCHANGE
