@@ -24,7 +24,7 @@ from xtcryptosignals.tasks import settings as s
 
 @use_mongodb(db=s.MONGODB_NAME, host=s.MONGODB_HOST, port=s.MONGODB_PORT)
 def _process(logger, socketio, exchange_class, schema_class, symbol, pairs):
-    ticker_kwargs = dict()
+    ticker_kwargs = {}
     if symbol:
         ticker_kwargs.update(symbol=symbol)
     elif pairs:
@@ -113,8 +113,8 @@ def update(self, *_, **kwargs):
         logging.getLogger("engineio").setLevel(log_level)
         logging.getLogger("socketio").setLevel(log_level)
 
-    jobs = []
     logger = self.get_logger()
+    jobs = []
 
     try:
         for row in s.SYMBOLS_PER_EXCHANGE:
